# Neutrosophic Calculator

A Python library for performing operations on neutrosophic sets. This library supports basic arithmetic and algebraic operations, as well as scalar multiplication.

## Installation

```bash
pip install neutrosophic
# netrosophic
